@@ -1,7 +1,7 @@
 """
 Type annotations for finspace-data service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/literals/)
 
 Usage::
 
@@ -42,6 +42,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -221,6 +222,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -421,3 +423,4 @@ ResourceServiceName = Literal[
 PaginatorName = Literal[
     "list_changesets", "list_data_views", "list_datasets", "list_permission_groups", "list_users"
 ]
+RegionName = Literal["ca-central-1", "eu-west-1", "us-east-1", "us-east-2", "us-west-2"]
