@@ -1,7 +1,7 @@
 """
 Type annotations for finspace-data service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/type_defs/)
 
 Usage::
 
@@ -78,14 +78,19 @@ __all__ = (
     "GetUserResponseTypeDef",
     "GetWorkingLocationRequestRequestTypeDef",
     "GetWorkingLocationResponseTypeDef",
+    "ListChangesetsRequestListChangesetsPaginateTypeDef",
     "ListChangesetsRequestRequestTypeDef",
     "ListChangesetsResponseTypeDef",
+    "ListDataViewsRequestListDataViewsPaginateTypeDef",
     "ListDataViewsRequestRequestTypeDef",
     "ListDataViewsResponseTypeDef",
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
     "ListDatasetsRequestRequestTypeDef",
     "ListDatasetsResponseTypeDef",
+    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
     "ListPermissionGroupsRequestRequestTypeDef",
     "ListPermissionGroupsResponseTypeDef",
+    "ListUsersRequestListUsersPaginateTypeDef",
     "ListUsersRequestRequestTypeDef",
     "ListUsersResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -520,6 +525,14 @@ GetWorkingLocationResponseTypeDef = TypedDict(
     },
 )
 
+ListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
+    "ListChangesetsRequestListChangesetsPaginateTypeDef",
+    {
+        "datasetId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListChangesetsRequestRequestTypeDef = TypedDict(
     "ListChangesetsRequestRequestTypeDef",
     {
@@ -538,6 +551,14 @@ ListChangesetsResponseTypeDef = TypedDict(
     },
 )
 
+ListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
+    "ListDataViewsRequestListDataViewsPaginateTypeDef",
+    {
+        "datasetId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListDataViewsRequestRequestTypeDef = TypedDict(
     "ListDataViewsRequestRequestTypeDef",
     {
@@ -556,6 +577,13 @@ ListDataViewsResponseTypeDef = TypedDict(
     },
 )
 
+ListDatasetsRequestListDatasetsPaginateTypeDef = TypedDict(
+    "ListDatasetsRequestListDatasetsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListDatasetsRequestRequestTypeDef = TypedDict(
     "ListDatasetsRequestRequestTypeDef",
     {
@@ -573,6 +601,13 @@ ListDatasetsResponseTypeDef = TypedDict(
     },
 )
 
+ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef = TypedDict(
+    "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPermissionGroupsRequestRequestTypeDef = TypedDict(
     "ListPermissionGroupsRequestRequestTypeDef",
     {
@@ -590,6 +625,13 @@ ListPermissionGroupsResponseTypeDef = TypedDict(
     },
 )
 
+ListUsersRequestListUsersPaginateTypeDef = TypedDict(
+    "ListUsersRequestListUsersPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListUsersRequestRequestTypeDef = TypedDict(
     "ListUsersRequestRequestTypeDef",
     {
